"""
Type annotations for botocore.retries.quota module.

Copyright 2025 Vlad Emelianov
"""

from threading import Lock

class RetryQuota:
    INITIAL_CAPACITY: int = ...
    def __init__(self, initial_capacity: int = ..., lock: Lock | None = ...) -> None: ...
    def acquire(self, capacity_amount: int) -> bool: ...
    def release(self, capacity_amount: int) -> None: ...
    @property
    def available_capacity(self) -> int: ...
